// This file shows how to model non-linear effects
// Paul Lambert 2024-08-11

clear all
set scheme fpsaus_c
global dofile stpm3_breast_NW_non_linear_functions

use breast_EW50 

// Linearity for age
use breast_nw if inlist(dep,1,5)
stset survtime, failure(dead==1) exit(time 5)
stpm3 i.dep agediag, scale(lncumhazard) df(5) eform nolog neq(1)
estimate store linear


// look at marginal predictions within age groups
stpm3km i.agegrp, legoptions(pos(7)) 
stpm3km i.agegrp, legoptions(pos(7)) ///
   note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))


// quadratic for age
gen agediag2 = agediag^2
stpm3 i.dep agediag agediag2, scale(lncumhazard) df(5) eform nolog neq(1)
estimate store quad1
predict S60dep5, surv ci frame(f1, replace)          /// 
                 at1(dep 5 agediag 60 agediag2 3600)

// quadratic for age using exended functions
stpm3 i.dep @poly(agediag,degree(2)), scale(lncumhazard) df(5) eform nolog neq(1)
estimate store quad2
predict S60dep5, surv ci frame(f1, replace)         /// 
                 at1(dep 5 agediag 60)

estimate tab quad1 quad2

// natural splines for age
stpm3 i.dep @ns(agediag,df(3)), scale(lncumhazard) df(5) eform nolog neq(1)
predict S60dep5, surv ci frame(f1, replace)         /// 
                 at1(dep 5 agediag 60)


// obtain hazard ratio for age
frame create agepred
frame agepred {
  range agediag 18 99 82
  gen dep = .
  gen t1 = 1
  predict h_dep1 h_dep5, hazard ci timevar(t1) merge ///
         at1(dep 1 agediag 60) at2(dep 1, obsvalues) ///
         contrast(ratio) contrastvar(hr)
}



frame agepred {
  twoway (line hr agediag)                                                 ///
         (rarea hr_lci hr_uci agediag, pstyle(p1line) color(%30))          ///
         , legend(off)                                                     ///
         yscale(log range(0.5 12))                                         ///
         ylabel(0.5 7 1 2 5 10, format(%3.1f))                              ///
         ytitle("Mortality Rate Ratio")                                    ///
         xtitle("Age at diagnosis")                                        ///
         yline(1,lpattern(-) lcolor(gs8))                                  ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
} 




// look at marginal predictions within age groups
stpm3km i.agegrp, legoptions(pos(7))
stpm3km i.agegrp, legoptions(pos(7)) ///
   note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))            


stpm3 i.dep##@ns(agediag,df(3)), scale(lncumhazard) df(5) eform nolog neq(1) vsquish
predict S60dep5, surv ci frame(f1, replace)         /// 
                 at1(dep 5 agediag 60)
            

capture frame drop S5pred           
frame create S5pred 
frame S5pred {
  range agediag 18 99 82
  gen dep = .
  gen t5 = 5
  predict S5dep1 S5dep5, survival ci merge timevar(t5)    ///
                         at1(dep 1, obsvalues) at2(dep 5, obsvalues) 
}    


frame S5pred {
  twoway (line S5dep1 S5dep5 agediag) ///
         (rarea S5dep1_lci S5dep1_uci agediag, pstyle(p1line) color(%30)) ///
         (rarea S5dep5_lci S5dep5_uci agediag, pstyle(p2line) color(%30)) ///
         , xtitle("Age at diagnosis")                                     ///
         ytitle("5-year survival")                                        ///
         ylabel(,format(%3.1f))                                           ///
         legend(off)                                                      ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}                
             
             
            
             
             
cap frame drop hrage
frame create hrage
frame hrage {
  range agediag 18 99 82
  gen dep = .
  gen t5 = 5
  predict , hazard ci merge nogen                                  ///
            timevar(t5)                                            ///
            at1(dep 1 agediag 60) at2(dep 1, obsvalues)            ///
            contrast(ratio) contrastvar(hrdep1)
  predict , hazard ci merge nogen                                  ///
            timevar(t5)                                            ///
            at1(dep 5 agediag 60) at2(dep 5, obsvalues)            ///
            contrast(ratio) contrastvar(hrdep5)            

}

frame hrage {
  twoway (line hrdep1 hrdep5 agediag) ///
         (rarea hrdep1_lci hrdep1_uci agediag, pstyle(p1line) color(%30)) ///
         (rarea hrdep5_lci hrdep5_uci agediag, pstyle(p2line) color(%30)) ///
         , xtitle("Age at diagnosis")                                     ///
         ytitle("Hazard ratio")                                           ///
         ylabel(0.5 0.7 1 1.5 2 10 20, format(%3.1f))                     ///
         yscale(log)                                                      ///
         legend(order(1 "Least deprived" 5 "Most Deprived") pos(11))      ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}                

// HR for deprivation
cap frame drop hrdep
frame create hrdep
frame hrdep {
  range agediag 18 99 82
  gen dep = .
  gen t5 = 5
  predict , hazard ci merge nogen                                  ///
            timevar(t5)                                            ///
            at1(dep 1, obsvalues) at2(dep 5, obsvalues)            ///
            contrast(ratio) contrastvar(hr)
}

frame hrdep {
  twoway (line hr  agediag) ///
         (rarea hr_lci hr_uci agediag, pstyle(p1line) color(%30)) ///
         , xtitle("Age at diagnosis")                                     ///
         ytitle("Hazard ratio")                                          ///
         ylabel(0.5 0.7 1 1.5 2 5, format(%3.1f))                     ///
         yscale(log range(0.5 5))                                                      ///
         legend(off)                                                      ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}                



stpm3 i.dep##@ns(agediag,df(3)), scale(lncumhazard) df(5) nolstretch nolog neq(0)  ///
      tvc(i.dep @ns(agediag,df(3))) dftvc(3)

capture frame drop hrage_tvc      
frame create hrage_tvc      
frame hrage_tvc {
  range agediag 18 99 82
  gen dep = .
  gen t1 = 1
  gen t5 = 5
  predict , hazard ci merge nogen                                  ///
            timevar(t1)                                            ///
            at1(dep 1 agediag 60) at2(dep 1, obsvalues)            ///
            contrast(ratio) contrastvar(hrdep1_t1)
  predict , hazard ci merge nogen                                  ///
            timevar(t5)                                            ///
            at1(dep 1 agediag 60) at2(dep 1, obsvalues)            ///
            contrast(ratio) contrastvar(hrdep1_t5)            
}

frame hrage_tvc {
  twoway (line hrdep1_t1 hrdep1_t5 agediag) ///
         (rarea hrdep1_t1_lci hrdep1_t1_uci agediag, pstyle(p1line) color(%30)) ///
         (rarea hrdep1_t5_lci hrdep1_t5_uci agediag, pstyle(p2line) color(%30)) ///
         , xtitle("Age at diagnosis")                                     ///
         ytitle("Hazard ratio")                                          ///
         ylabel(0.5 0.7 1 1.5 2 10 20, format(%3.1f))                     ///
         yscale(log)                                                      ///
         legend(off)                                                      ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}                

// marginal predictions
range tt 0 5 101
standsurv, surv ci timevar(tt) frame(Sm,replace)   ///
           at1(dep 1) at2(dep 5) atvar(S1 S5)      ///
           contrast(difference) contrastvar(Sdiff)
 

frame Sm {
  twoway (line Sdiff tt) ///
         (rarea Sdiff_lci Sdiff_uci tt, pstyle(p1line) color(%30)) ///
         , xtitle("Time since diagnosis (years)")                  ///
         ytitle("Difference in marginal survival")                 ///
         ylabel(,format(%3.2f))                                    ///
         legend(off)                                               ///
         note("Graph code in ${dofile}", size(vsmall) span color(gs3%50))
}                
